@@ -368,7 +368,7 @@ class LSrelation {
               $data['id'] = $_REQUEST['id'];
             }
             else {
-              LSerror :: addErrorCode('LSrelations_03',$relationName);
+              LSerror :: addErrorCode('LSrelations_03', $conf['relationName']);
             }
           }
           else {
@@ -467,3 +467,4 @@ _("LSrelation : Incomplete configuration for LSrelation %{relation} of object ty
 LSerror :: defineError('LSrelations_06',
 _("LSrelation : Invalid editable attribute for LSrelation %{relation} with LSobject %{LSobject}.")
 );
+
