@@ -1,18 +1,18 @@
 <?php
-/* Smarty version {Smarty::SMARTY_VERSION}, created on 2018-10-01 12:53:41
+/* Smarty version {Smarty::SMARTY_VERSION}, created on 2019-06-05 10:24:32
   from "ls:viewSearch.tpl" */
 
 /* @var Smarty_Internal_Template $_smarty_tpl */
 if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
   'version' => '3.1.31',
-  'unifunc' => 'content_5bb218d53b2111_84402511',
+  'unifunc' => 'content_5cf798604dab55_89119269',
   'has_nocache_code' => false,
   'file_dependency' => 
   array (
     '7e5e1b40a6897e6cd2a4b75f034a469f40dd849c' => 
     array (
       0 => 'ls:viewSearch.tpl',
-      1 => 1537449273,
+      1 => 1559564613,
       2 => 'ls',
     ),
   ),
@@ -22,7 +22,7 @@ if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
     'ls:bottom.tpl' => 1,
   ),
 ),false)) {
-function content_5bb218d53b2111_84402511 (Smarty_Internal_Template $_smarty_tpl) {
+function content_5cf798604dab55_89119269 (Smarty_Internal_Template $_smarty_tpl) {
 if (!is_callable('smarty_function_html_options')) require_once '/usr/share/php/smarty3/plugins/function.html_options.php';
 if (!is_callable('smarty_function_cycle')) require_once '/usr/share/php/smarty3/plugins/function.cycle.php';
 $_smarty_tpl->_subTemplateRender('ls:top.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, $_smarty_tpl->cache_lifetime, array(), 0, false);
@@ -75,9 +75,9 @@ foreach ($_from as $_smarty_tpl->tpl_vars['item']->value) {
     <?php if (is_array($_smarty_tpl->tpl_vars['item']->value)) {?>
       <li class='LSview-actions'><a href='<?php echo $_smarty_tpl->tpl_vars['item']->value['url'];?>
 ' class='LSview-actions'><img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['item']->value['action']),$_smarty_tpl);?>
-' alt='<?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['label']->value),$_smarty_tpl);?>
-' title='<?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['label']->value),$_smarty_tpl);?>
-' /> <?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['item']->value['label']),$_smarty_tpl);?>
+' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['item']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
+' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['item']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
+' /> <?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['item']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
 </a></li>
     <?php }?>
   <?php
