@@ -1,18 +1,18 @@
 <?php
-/* Smarty version {Smarty::SMARTY_VERSION}, created on 2018-10-01 12:53:42
+/* Smarty version {Smarty::SMARTY_VERSION}, created on 2019-06-05 10:38:14
   from "ls:LSformview.tpl" */
 
 /* @var Smarty_Internal_Template $_smarty_tpl */
 if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
   'version' => '3.1.31',
-  'unifunc' => 'content_5bb218d6a69a44_73193981',
+  'unifunc' => 'content_5cf79b96828115_91133114',
   'has_nocache_code' => false,
   'file_dependency' => 
   array (
     'f237a4591f3ed336d8fdb8a71822083d249608cd' => 
     array (
       0 => 'ls:LSformview.tpl',
-      1 => 1535729413,
+      1 => 1553870226,
       2 => 'ls',
     ),
   ),
@@ -20,7 +20,7 @@ if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
   array (
   ),
 ),false)) {
-function content_5bb218d6a69a44_73193981 (Smarty_Internal_Template $_smarty_tpl) {
+function content_5cf79b96828115_91133114 (Smarty_Internal_Template $_smarty_tpl) {
 ?>
 <input type='hidden' name='LSform_objecttype' id='LSform_objecttype'  value='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSform_object']->value['type'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
 '/>
@@ -80,8 +80,10 @@ foreach ($_from as $_smarty_tpl->tpl_vars['arg']->value) {
           <?php if ($_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]) {?>
             <?php $_smarty_tpl->_assignInScope('field', 'oui');
 ?>
-            <dt class='LSform'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
-</dt>
+            <dt class='LSform'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');
+if ($_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['help_info_in_view'] && $_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['help_info'] != '') {?> <img class='LStips' src="<?php echo LStemplate_smarty_img(array('name'=>'help'),$_smarty_tpl);?>
+" alt='?' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['help_info'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
+'/><?php }?></dt>
             <dd class='LSform'><?php echo $_smarty_tpl->tpl_vars['LSform_fields']->value[$_smarty_tpl->tpl_vars['arg']->value]['html'];?>
 </dd>
           <?php }?>
